@@ -30,10 +30,10 @@ int main() {
 
 	int result = lua["f"](1, 2);
 	// result == 3
-	sol_c_assert(result == 3);
+	SOL_ASSERT(result == 3);
 	double result2 = lua["f"](false, 2.5);
 	// result2 == 2.5
-	sol_c_assert(result2 == 2.5);
+	SOL_ASSERT(result2 == 2.5);
 
 	// call in Lua, get result
 	// notice we only need 2 arguments here, not 3
@@ -41,7 +41,7 @@ int main() {
 	lua.script("result3 = f(true, 5.5)");
 	double result3 = lua["result3"];
 	// result3 == 16.5
-	sol_c_assert(result3 == 16.5);
+	SOL_ASSERT(result3 == 16.5);
 
 	std::cout << "=== any_return ===" << std::endl;
 	std::cout << "result : " << result << std::endl;
@@ -50,4 +50,4 @@ int main() {
 	std::cout << std::endl;
 
 	return 0;
-}
\ No newline at end of file
+}
