@@ -45,7 +45,7 @@ int main(int, char*[]) {
 	transferred_into();
 	// check
 	int i = lua["i"];
-	sol_c_assert(i == 1);
+	SOL_ASSERT(i == 1);
 
 	std::cout << std::endl;
 
