@@ -9,11 +9,11 @@ int main(int, char*[]) {
 	lua.script("exists = 250");
 
 	int first_try = lua.get_or("exists", 322);
-	sol_c_assert(first_try == 250);
+	SOL_ASSERT(first_try == 250);
 
 	lua.set("exists", sol::lua_nil);
 	int second_try = lua.get_or("exists", 322);
-	sol_c_assert(second_try == 322);
+	SOL_ASSERT(second_try == 322);
 
 	return 0;
 }
