@@ -22,8 +22,8 @@ int main() {
 	     "my_str = my_combine('bark bark', ' woof woof')");
 	int my_num = lua["my_num"];
 	std::string my_str = lua["my_str"];
-	sol_c_assert(my_num == 3);
-	sol_c_assert(my_str == "bark bark woof woof");
+	SOL_ASSERT(my_num == 3);
+	SOL_ASSERT(my_str == "bark bark woof woof");
 
 	return 0;
 }
