@@ -29,9 +29,9 @@
 // clang-format off
 
 #define SOL_VERSION_MAJOR 3
-#define SOL_VERSION_MINOR 2
-#define SOL_VERSION_PATCH 3
-#define SOL_VERSION_STRING "3.2.3"
+#define SOL_VERSION_MINOR 5
+#define SOL_VERSION_PATCH 0
+#define SOL_VERSION_STRING "3.5.0"
 #define SOL_VERSION ((SOL_VERSION_MAJOR * 100000) + (SOL_VERSION_MINOR * 100) + (SOL_VERSION_PATCH))
 
 #define SOL_TOKEN_TO_STRING_POST_EXPANSION_I_(_TOKEN) #_TOKEN
@@ -40,6 +40,7 @@
 #define SOL_CONCAT_TOKENS_POST_EXPANSION_I_(_LEFT, _RIGHT) _LEFT##_RIGHT
 #define SOL_CONCAT_TOKENS_I_(_LEFT, _RIGHT) SOL_CONCAT_TOKENS_POST_EXPANSION_I_(_LEFT, _RIGHT)
 
+#define SOL_RAW_USE(SYMBOL) SYMBOL
 #define SOL_RAW_IS_ON(OP_SYMBOL) ((3 OP_SYMBOL 3) != 0)
 #define SOL_RAW_IS_OFF(OP_SYMBOL) ((3 OP_SYMBOL 3) == 0)
 #define SOL_RAW_IS_DEFAULT_ON(OP_SYMBOL) ((3 OP_SYMBOL 3) > 3)
@@ -49,6 +50,7 @@
 #define SOL_IS_OFF(OP_SYMBOL) SOL_RAW_IS_OFF(OP_SYMBOL ## _I_)
 #define SOL_IS_DEFAULT_ON(OP_SYMBOL) SOL_RAW_IS_DEFAULT_ON(OP_SYMBOL ## _I_)
 #define SOL_IS_DEFAULT_OFF(OP_SYMBOL) SOL_RAW_IS_DEFAULT_OFF(OP_SYMBOL ## _I_)
+#define SOL_USE(SYMBOL) SOL_RAW_USE(SYMBOL ## _I_)
 
 #define SOL_ON          |
 #define SOL_OFF         ^
@@ -89,8 +91,16 @@
 	#include <climits>
 #endif
 
+#if defined(SOL_HAS_BUILTIN)
+	#define SOL_HAS_BUILTIN_I_(...) SOL_HAS_BUILTIN(__VA_ARGS__)
+#elif defined(__has_builtin)
+	#define SOL_HAS_BUILTIN_I_(...) __has_builtin(__VA_ARGS__)
+#else
+	#define SOL_HAS_BUILTIN_I_(...) 0
+#endif
+
 #if defined(SOL_COMPILER_VCXX)
-	#if defined(SOL_COMPILER_VCXX != 0)
+	#if (SOL_COMPILER_VCXX != 0)
 		#define SOL_COMPILER_VCXX_I_ SOL_ON
 	#else
 		#define SOL_COMPILER_VCXX_I_ SOL_OFF
@@ -102,7 +112,7 @@
 #endif
 
 #if defined(SOL_COMPILER_GCC)
-	#if defined(SOL_COMPILER_GCC != 0)
+	#if (SOL_COMPILER_GCC != 0)
 		#define SOL_COMPILER_GCC_I_ SOL_ON
 	#else
 		#define SOL_COMPILER_GCC_I_ SOL_OFF
@@ -114,7 +124,7 @@
 #endif
 
 #if defined(SOL_COMPILER_CLANG)
-	#if defined(SOL_COMPILER_CLANG != 0)
+	#if (SOL_COMPILER_CLANG != 0)
 		#define SOL_COMPILER_CLANG_I_ SOL_ON
 	#else
 		#define SOL_COMPILER_CLANG_I_ SOL_OFF
@@ -126,7 +136,7 @@
 #endif
 
 #if defined(SOL_COMPILER_EDG)
-	#if defined(SOL_COMPILER_EDG != 0)
+	#if (SOL_COMPILER_EDG != 0)
 		#define SOL_COMPILER_EDG_I_ SOL_ON
 	#else
 		#define SOL_COMPILER_EDG_I_ SOL_OFF
@@ -208,7 +218,7 @@
 		#define SOL_PLATFORM_UNIXLIKE_I_ SOL_OFF
 	#endif
 #elif defined(__unix__)
-	#define SOL_PLATFORM_UNIXLIKE_I_ SOL_DEFAUKT_ON
+	#define SOL_PLATFORM_UNIXLIKE_I_ SOL_DEFAULT_ON
 #else
 	#define SOL_PLATFORM_UNIXLIKE_I_ SOL_DEFAULT_OFF
 #endif
@@ -220,7 +230,7 @@
 		#define SOL_PLATFORM_LINUXLIKE_I_ SOL_OFF
 	#endif
 #elif defined(__LINUX__)
-	#define SOL_PLATFORM_LINUXLIKE_I_ SOL_DEFAUKT_ON
+	#define SOL_PLATFORM_LINUXLIKE_I_ SOL_DEFAULT_ON
 #else
 	#define SOL_PLATFORM_LINUXLIKE_I_ SOL_DEFAULT_OFF
 #endif
@@ -229,7 +239,7 @@
 #define SOL_PLATFORM_BSDLIKE_I_      SOL_OFF
 
 #if defined(SOL_IN_DEBUG_DETECTED)
-	#if SOL_IN_DEBUG_DETECTED != 0
+	#if (SOL_IN_DEBUG_DETECTED != 0)
 		#define SOL_DEBUG_BUILD_I_ SOL_ON
 	#else
 		#define SOL_DEBUG_BUILD_I_ SOL_OFF
@@ -292,7 +302,7 @@
 #endif
 
 #if defined(SOL_NO_THREAD_LOCAL)
-	#if SOL_NO_THREAD_LOCAL != 0
+	#if (SOL_NO_THREAD_LOCAL != 0)
 		#define SOL_USE_THREAD_LOCAL_I_ SOL_OFF
 	#else
 		#define SOL_USE_THREAD_LOCAL_I_ SOL_ON
@@ -302,7 +312,7 @@
 #endif // thread_local keyword is bjorked on some platforms
 
 #if defined(SOL_ALL_SAFETIES_ON)
-	#if SOL_ALL_SAFETIES_ON != 0
+	#if (SOL_ALL_SAFETIES_ON != 0)
 		#define SOL_ALL_SAFETIES_ON_I_ SOL_ON
 	#else
 		#define SOL_ALL_SAFETIES_ON_I_ SOL_OFF
@@ -312,7 +322,7 @@
 #endif
 
 #if defined(SOL_SAFE_GETTER)
-	#if SOL_SAFE_GETTER != 0
+	#if (SOL_SAFE_GETTER != 0)
 		#define SOL_SAFE_GETTER_I_ SOL_ON
 	#else
 		#define SOL_SAFE_GETTER_I_ SOL_OFF
@@ -328,7 +338,7 @@
 #endif
 
 #if defined(SOL_SAFE_USERTYPE)
-	#if SOL_SAFE_USERTYPE != 0
+	#if (SOL_SAFE_USERTYPE != 0)
 		#define SOL_SAFE_USERTYPE_I_ SOL_ON
 	#else
 		#define SOL_SAFE_USERTYPE_I_ SOL_OFF
@@ -344,7 +354,7 @@
 #endif
 
 #if defined(SOL_SAFE_REFERENCES)
-	#if SOL_SAFE_REFERENCES != 0
+	#if (SOL_SAFE_REFERENCES != 0)
 		#define SOL_SAFE_REFERENCES_I_ SOL_ON
 	#else
 		#define SOL_SAFE_REFERENCES_I_ SOL_OFF
@@ -360,13 +370,13 @@
 #endif
 
 #if defined(SOL_SAFE_FUNCTIONS)
-	#if SOL_SAFE_FUNCTIONS != 0
+	#if (SOL_SAFE_FUNCTIONS != 0)
 		#define SOL_SAFE_FUNCTION_OBJECTS_I_ SOL_ON
 	#else
 		#define SOL_SAFE_FUNCTION_OBJECTS_I_ SOL_OFF
 	#endif
 #elif defined (SOL_SAFE_FUNCTION_OBJECTS)
-	#if SOL_SAFE_FUNCTION_OBJECTS != 0
+	#if (SOL_SAFE_FUNCTION_OBJECTS != 0)
 		#define SOL_SAFE_FUNCTION_OBJECTS_I_ SOL_ON
 	#else
 		#define SOL_SAFE_FUNCTION_OBJECTS_I_ SOL_OFF
@@ -382,7 +392,7 @@
 #endif
 
 #if defined(SOL_SAFE_FUNCTION_CALLS)
-	#if SOL_SAFE_FUNCTION_CALLS != 0
+	#if (SOL_SAFE_FUNCTION_CALLS != 0)
 		#define SOL_SAFE_FUNCTION_CALLS_I_ SOL_ON
 	#else
 		#define SOL_SAFE_FUNCTION_CALLS_I_ SOL_OFF
@@ -398,7 +408,7 @@
 #endif
 
 #if defined(SOL_SAFE_PROXIES)
-	#if SOL_SAFE_PROXIES != 0
+	#if (SOL_SAFE_PROXIES != 0)
 		#define SOL_SAFE_PROXIES_I_ SOL_ON
 	#else
 		#define SOL_SAFE_PROXIES_I_ SOL_OFF
@@ -414,7 +424,7 @@
 #endif
 
 #if defined(SOL_SAFE_NUMERICS)
-	#if SOL_SAFE_NUMERICS != 0
+	#if (SOL_SAFE_NUMERICS != 0)
 		#define SOL_SAFE_NUMERICS_I_ SOL_ON
 	#else
 		#define SOL_SAFE_NUMERICS_I_ SOL_OFF
@@ -444,7 +454,7 @@
 #endif
 
 #if defined(SOL_SAFE_STACK_CHECK)
-	#if SOL_SAFE_STACK_CHECK != 0
+	#if (SOL_SAFE_STACK_CHECK != 0)
 		#define SOL_SAFE_STACK_CHECK_I_ SOL_ON
 	#else
 		#define SOL_SAFE_STACK_CHECK_I_ SOL_OFF
@@ -460,13 +470,13 @@
 #endif
 
 #if defined(SOL_NO_CHECK_NUMBER_PRECISION)
-	#if SOL_NO_CHECK_NUMBER_PRECISION != 0
+	#if (SOL_NO_CHECK_NUMBER_PRECISION != 0)
 		#define SOL_NUMBER_PRECISION_CHECKS_I_ SOL_OFF
 	#else
 		#define SOL_NUMBER_PRECISION_CHECKS_I_ SOL_ON
 	#endif
 #elif defined(SOL_NO_CHECKING_NUMBER_PRECISION)
-	#if SOL_NO_CHECKING_NUMBER_PRECISION != 0
+	#if (SOL_NO_CHECKING_NUMBER_PRECISION != 0)
 		#define SOL_NUMBER_PRECISION_CHECKS_I_ SOL_OFF
 	#else
 		#define SOL_NUMBER_PRECISION_CHECKS_I_ SOL_ON
@@ -494,13 +504,13 @@
 #endif
 
 #if defined(SOL_ENABLE_INTEROP)
-	#if SOL_ENABLE_INTEROP != 0
+	#if (SOL_ENABLE_INTEROP != 0)
 		#define SOL_USE_INTEROP_I_ SOL_ON
 	#else
 		#define SOL_USE_INTEROP_I_ SOL_OFF
 	#endif
 #elif defined(SOL_USE_INTEROP)
-	#if SOL_USE_INTEROP != 0
+	#if (SOL_USE_INTEROP != 0)
 		#define SOL_USE_INTEROP_I_ SOL_ON
 	#else
 		#define SOL_USE_INTEROP_I_ SOL_OFF
@@ -590,19 +600,19 @@
 	#endif
 #endif // noexcept is part of a function's type
 
-#if defined(SOL_STACK_STRING_OPTIMIZATION_SIZE) && SOL_STACK_STRING_OPTIMIZATION_SIZE > 0
+#if defined(SOL_STACK_STRING_OPTIMIZATION_SIZE) && (SOL_STACK_STRING_OPTIMIZATION_SIZE > 0)
 	#define SOL_OPTIMIZATION_STRING_CONVERSION_STACK_SIZE_I_ SOL_STACK_STRING_OPTIMIZATION_SIZE
 #else
 	#define SOL_OPTIMIZATION_STRING_CONVERSION_STACK_SIZE_I_ 1024
 #endif
 
-#if defined(SOL_ID_SIZE) && SOL_ID_SIZE > 0
+#if defined(SOL_ID_SIZE) && (SOL_ID_SIZE > 0)
 	#define SOL_ID_SIZE_I_ SOL_ID_SIZE
 #else
 	#define SOL_ID_SIZE_I_ 512
 #endif
 
-#if defined(LUA_IDSIZE) && LUA_IDSIZE > 0
+#if defined(LUA_IDSIZE) && (LUA_IDSIZE > 0)
 	#define SOL_FILE_ID_SIZE_I_ LUA_IDSIZE
 #elif defined(SOL_ID_SIZE) && SOL_ID_SIZE > 0
 	#define SOL_FILE_ID_SIZE_I_ SOL_FILE_ID_SIZE
@@ -638,34 +648,35 @@
 
 #if defined(SOL_USING_CXX_LUA)
 	#if (SOL_USING_CXX_LUA != 0)
-		#define SOL_USE_CXX_LUA_I_ SOL_ON
+		#define SOL_USING_CXX_LUA_I_ SOL_ON
 	#else
-		#define SOL_USE_CXX_LUA_I_ SOL_OFF
+		#define SOL_USING_CXX_LUA_I_ SOL_OFF
 	#endif
 #elif defined(SOL_USE_CXX_LUA)
+	// alternative spelling
 	#if (SOL_USE_CXX_LUA != 0)
-		#define SOL_USE_CXX_LUA_I_ SOL_ON
+		#define SOL_USING_CXX_LUA_I_ SOL_ON
 	#else
-		#define SOL_USE_CXX_LUA_I_ SOL_OFF
+		#define SOL_USING_CXX_LUA_I_ SOL_OFF
 	#endif
 #else
-	#define SOL_USE_CXX_LUA_I_ SOL_DEFAULT_OFF
+	#define SOL_USING_CXX_LUA_I_ SOL_DEFAULT_OFF
 #endif
 
 #if defined(SOL_USING_CXX_LUAJIT)
-	#if (SOL_USING_CXX_LUA != 0)
-		#define SOL_USE_CXX_LUAJIT_I_ SOL_ON
+	#if (SOL_USING_CXX_LUAJIT != 0)
+		#define SOL_USING_CXX_LUAJIT_I_ SOL_ON
 	#else
-		#define SOL_USE_CXX_LUAJIT_I_ SOL_OFF
+		#define SOL_USING_CXX_LUAJIT_I_ SOL_OFF
 	#endif
 #elif defined(SOL_USE_CXX_LUAJIT)
-	#if (SOL_USE_CXX_LUA != 0)
-		#define SOL_USE_CXX_LUAJIT_I_ SOL_ON
+	#if (SOL_USE_CXX_LUAJIT != 0)
+		#define SOL_USING_CXX_LUAJIT_I_ SOL_ON
 	#else
-		#define SOL_USE_CXX_LUAJIT_I_ SOL_OFF
+		#define SOL_USING_CXX_LUAJIT_I_ SOL_OFF
 	#endif
 #else
-	#define SOL_USE_CXX_LUAJIT_I_ SOL_DEFAULT_OFF
+	#define SOL_USING_CXX_LUAJIT_I_ SOL_DEFAULT_OFF
 #endif
 
 #if defined(SOL_NO_LUA_HPP)
@@ -674,7 +685,7 @@
 	#else
 		#define SOL_USE_LUA_HPP_I_ SOL_ON
 	#endif
-#elif defined(SOL_USING_CXX_LUA)
+#elif SOL_IS_ON(SOL_USING_CXX_LUA)
 	#define SOL_USE_LUA_HPP_I_ SOL_OFF
 #elif defined(__has_include)
 	#if __has_include(<lua.hpp>)
@@ -760,6 +771,16 @@
 	#define SOL_GET_FUNCTION_POINTER_UNSAFE_I_ SOL_DEFAULT_OFF
 #endif
 
+#if defined(SOL_CONTAINER_CHECK_IS_EXHAUSTIVE)
+	#if (SOL_CONTAINER_CHECK_IS_EXHAUSTIVE != 0)
+		#define SOL_CONTAINER_CHECK_IS_EXHAUSTIVE_I_ SOL_ON
+	#else
+		#define SOL_CONTAINER_CHECK_IS_EXHAUSTIVE_I_ SOL_OFF
+	#endif
+#else
+	#define SOL_CONTAINER_CHECK_IS_EXHAUSTIVE_I_ SOL_DEFAULT_OFF
+#endif
+
 #if defined(SOL_FUNCTION_CALL_VALUE_SEMANTICS)
 	#if (SOL_FUNCTION_CALL_VALUE_SEMANTICS != 0)
 		#define SOL_FUNCTION_CALL_VALUE_SEMANTICS_I_ SOL_ON
@@ -820,16 +841,16 @@
 	#define SOL2_CI_I_ SOL_DEFAULT_OFF
 #endif
 
-#if defined(SOL_C_ASSERT)
-	#define SOL_USER_C_ASSERT_I_ SOL_ON
+#if defined(SOL_ASSERT)
+	#define SOL_USER_ASSERT_I_ SOL_ON
 #else
-	#define SOL_USER_C_ASSERT_I_ SOL_DEFAULT_OFF
+	#define SOL_USER_ASSERT_I_ SOL_DEFAULT_OFF
 #endif
 
-#if defined(SOL_M_ASSERT)
-	#define SOL_USER_M_ASSERT_I_ SOL_ON
+#if defined(SOL_ASSERT_MSG)
+	#define SOL_USER_ASSERT_MSG_I_ SOL_ON
 #else
-	#define SOL_USER_M_ASSERT_I_ SOL_DEFAULT_OFF
+	#define SOL_USER_ASSERT_MSG_I_ SOL_DEFAULT_OFF
 #endif
 
 #include <sol/prologue.hpp>
